# AP2100
#
# Script for AP Invoice Entry.  
# Assumes you have AP Invoice Detail Optional Fields SUBSTENTITY and PROJECT
# Adds the two optional fields into the AP Invoice entry grid. 
# You can drag & drop them to the left hand side of the grid if required.

from accpac import *

def main(args):
	MyUI()

class MyUI(UI):
	def __init__(self):
		UI.__init__(self)
		self.createScreen()

	def createScreen(self):
		grid = self.getHostControl("avlAPIBD")
		self.grid = grid

		col = UIGridColumn()
		col.caption = "Entity"
		col.hasFinder = True
		col.isEditable = True
		grid.addColumn(col)

		col = UIGridColumn()
		col.caption = "Project"
		col.hasFinder = True
		col.isEditable = True
		grid.addColumn(col)

		grid.setOnFinder(self.onGridFinder)
		grid.setOnBeginEdit(self.onGridBeginEdit)
		grid.setOnAfterEdit(self.onGridAfterEdit)
		grid.setOnGetText(self.onGridGetText)

		self.ds = self.openDataSource("adsAPIBDO")
		grid.refreshData()
		self.show()

	def onGridBeginEdit(self, e):
		if e.caption == "Entity":
			e.datatype = "TEXT"
			e.width = 10
			e.mask = "%-10C"
			self.onGridGetText(e)
		if e.caption == "Project":
			e.datatype = "TEXT"
			e.width = 10
			e.mask = "%-10C"
			self.onGridGetText(e)

	def onGridAfterEdit(self, e):
		if e.caption == "Entity":
			self.setOptionalField("SUBSTENTITY", e.value)
		if e.caption == "Project":
			self.setOptionalField("PROJECT", e.value)

	def setOptionalField(self, optfield, value):
			self.ds.put("OPTFIELD", optfield)
			if self.ds.read() == 0:
				self.ds.put("VALUE", value)
				self.ds.update()
			else:
				self.ds.recordGenerate()
				self.ds.put("OPTFIELD", optfield)
				self.ds.put("VALUE", value)
				self.ds.insert()

	def onGridGetText(self, e):
		if e.caption == "Entity":
			self.ds.put("OPTFIELD", "SUBSTENTITY")
			if self.ds.read() == 0:
				e.value = self.ds.get("VALUE")
			else:
				e.value = ""

		if e.caption == "Project":
			self.ds.put("OPTFIELD", "PROJECT")
			if self.ds.read() == 0:
				e.value = self.ds.get("VALUE")
			else:
				e.value = ""

	def onGridFinder(self, fieldName, caption):
		if caption == "Entity":
			finder = Finder()
			finder.viewID = "CS0012"
			finder.displayFields = "2,4"
			finder.returnFields = "2"
			finder.filter = "OPTFIELD=\"SUBSTENTITY\""
			finder.onOK = self.finder_ok
			finder.onCancel = self.finder_cancel
			finder.show(self)
		if caption == "Project":
			finder = Finder()
			finder.viewID = "CS0012"
			finder.displayFields = "2,4"
			finder.returnFields = "2"
			finder.filter = "OPTFIELD=\"PROJECT\""
			finder.onOK = self.finder_ok
			finder.onCancel = self.finder_cancel
			finder.show(self)

	def finder_ok(self, e):
		self.grid.endEdit(e)

	def finder_cancel(self):
		self.grid.preventFinder()
